"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var tsioc_1 = require("tsioc");
var util_1 = require("./util");
/**
 * mvc configuration
 *
 * @export
 * @interface Configuration
 */
var Configuration = /** @class */ (function () {
    function Configuration() {
        this.assertUrlRegExp = /\/((\w|%|\.))+\.\w+$/;
        this.routeUrlRegExp = null;
        /**
         * hostname.
         *
         * @memberof Configuration
         */
        this.hostname = '';
        /**
         * port
         *
         * @memberof Configuration
         */
        this.port = 3000;
        /**
         * system file root directory.
         */
        this.rootdir = '';
        this.session = {
            key: 'typemvc:sess',
            /** (number || 'session') maxAge in ms (default is 1 days) */
            /** 'session' will result in a cookie that expires when session/browser is closed */
            /** Warning: If a session cookie is stolen, this cookie will never expire */
            maxAge: 86400000,
            overwrite: true,
            httpOnly: true,
            signed: true,
            rolling: false /** (boolean) Force a session identifier cookie to be set on every response. The expiration is reset to the original maxAge, resetting the expiration countdown. default is false **/
        };
        /**
         * contents path of files, static files. default in 'public'
         *
         * @type {(string | string[])}
         * @memberof Configuration
         */
        this.contents = ['./public'];
        /**
         * web site base url path. route prefix.
         *
         * @type {string}
         * @memberOf Configuration
         */
        this.routePrefix = '';
        /**
         * custom config key value setting.
         *
         * @type {IMap<any>}
         * @memberOf Configuration
         */
        this.setting = {};
        /**
         * custom config connections.
         *
         * @type {ObjectMap<any>}
         * @memberof Configuration
         */
        this.connections = {};
        /**
         * some middleware befor router middleware to deal with http request.
         *
         * @type {Token<any>[]}
         * @memberof Configuration
         */
        this.beforeMiddlewares = [
            util_1.symbols.BodyParserMiddleware,
            util_1.symbols.JsonMiddleware,
            util_1.symbols.LogMiddleware,
            util_1.symbols.SessionMiddleware,
            util_1.symbols.ContentMiddleware,
            util_1.symbols.ContextMiddleware,
            util_1.symbols.CorsMiddleware,
            util_1.symbols.ViewsMiddleware
        ];
        /**
         * the router middleware.
         *
         * @type {Token<any>}
         * @memberof Configuration
         */
        this.routerMiddlewate = util_1.symbols.RouterMiddleware;
        /**
         * custom middleware match path, './middlewares/\*\*\/*{.js,.ts}' in your project.
         */
        this.middlewares = ['./middlewares/**/*{.js,.ts}'];
        /**
         * some middleware after router middleware to deal with http request.
         *
         * @type {Token<any>[]}
         * @memberof Configuration
         */
        this.afterMiddlewares = [];
        /**
         * exclude some middlewares
         *
         * @type {Token<any>[]}
         * @memberof Configuration
         */
        this.excludeMiddlewares = [];
        /**
         * use middlewars. if not config will load all.
         *
         * @type {Token<any>[]}
         * @memberof Configuration
         */
        this.useMiddlewares = [];
        /**
         * controllers match. default `./controllers/\*\*\/*{.js,.ts}` in your project..
         *
         * @type {(string | string[])}
         * @memberOf Configuration
         */
        this.controllers = ['./controllers/**/*{.js,.ts}'];
        /**
         * use controllers. if not config will load all.
         *
         * @type {Token<any>[]}
         * @memberof Configuration
         */
        this.useControllers = [];
        /**
         * custom aop services. default './aop/\*\*\/*{.js,.ts}'
         *
         * @type {(string | string[])}
         * @memberof Configuration
         */
        this.aop = ['./aop/**/*{.js,.ts}'];
        /**
         * used aop
         *
         * @type {Token<any>[]}
         * @memberof Configuration
         */
        this.usedAops = [];
        /**
         * views folder, default `./views` in your project.
         *
         * @memberof Configuration
         */
        this.views = './views';
        /**
         * render view options.
         *
         * @memberof Configuration
         */
        this.viewsOptions = {
            extension: 'ejs',
            map: { html: 'nunjucks' }
        };
        this.modelOptions = null;
    }
    Configuration.prototype.isRouteUrl = function (ctxUrl) {
        var flag = !this.assertUrlRegExp.test(ctxUrl);
        if (flag && this.routeUrlRegExp) {
            return this.routeUrlRegExp.test(ctxUrl);
        }
        return flag;
    };
    Configuration = __decorate([
        tsioc_1.Singleton,
        __metadata("design:paramtypes", [])
    ], Configuration);
    return Configuration;
}());
exports.Configuration = Configuration;

//# sourceMappingURL=sourcemaps/Configuration.js.map
